@@ -120,19 +120,25 @@ static const char * getAppName(bool useTQt=true)
 
 int TQApplication::exec()
 {
-    static bool init=false;
+	static bool init=false;
 
-    if(!init)
-    {
-        connectToKDialogD(getAppName(false));
-        init=true;
-    }
+	if(!init)
+	{
+		connectToKDialogD(getAppName(false));
+		init=true;
+	}
 
-    static int (*realFunction)(void *);
+	static int (*realFunction)(void *);
 
-    if(!realFunction)
-        realFunction = (int (*)(void *)) dlsym(RTLD_NEXT, KQT_QAPPLICATION_EXEC);
-    return (int)realFunction(this);
+	if(!realFunction)
+		realFunction = (int (*)(void *)) dlsym(RTLD_NEXT, KQT_QAPPLICATION_EXEC);
+	if (realFunction)
+		return (int)realFunction(this);
+	else
+	{
+		tqWarning("kgtk-qt3 tqt TQApplication::exec() realFunction not found!!");
+		return 255;
+	}
 };
 
 static TQString qt2KdeFilter(const TQString &f)
